@@ -4,13 +4,13 @@ from unit_timeside import *
 import timeside
 verbose = 0
 
-class TestListCoreProcessors(TestCase):
+class TestListCoreProcessors(unittest.TestCase):
     """ test get list of processors """
 
     def testHasSomeDecoders(self):
         "has some decoders"
-        import timeside.encoder
-        procs = timeside.core.processors(timeside.api.IEncoder)
+        import timeside.decoder
+        procs = timeside.core.processors(timeside.api.IDecoder)
         self.assertNotEquals(len(procs), 0)
 
     def testHasSomeEncoders(self):
