@@ -21,10 +21,11 @@
 #   Guillaume Pellerin <yomguy at parisson.com>
 #   Paul Brossier <piem@piem.org>
 #   Thomas Fillon <thomas  at parisson.com>
+
 from __future__ import division
 
 from timeside.core import Processor
-import timeside #import __version__
+import timeside  # import __version__
 import numpy
 from collections import OrderedDict
 import h5py
@@ -37,6 +38,8 @@ if 'DISPLAY' not in os.environ:
     matplotlib.use('Agg')
 
 import matplotlib.pyplot as plt
+from matplotlib.figure import Figure
+from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas
 
 numpy_data_types = [
     #'float128',
@@ -51,8 +54,9 @@ numpy_data_types = [
     'uint32',
     'uint16',
     'uint8',
+    #'unicode_', Strings should be handled through label_metadata
+    #'string_',
     'object_',
-    'string_',
     'longlong',
     #'timedelta64',
     #'datetime64',
@@ -238,6 +242,10 @@ class AudioMetadata(MetadataObject):
             Start time of the segment in seconds
         duration : float
             Duration of the segment in seconds
+        is_segment : boolean
+            Is the media a segment of an audio source
+        sha1 : str
+            Sha1 hexadecimal digest of the audio source
         channels : int
             Number of channels
         channelsManagement : str
@@ -254,6 +262,7 @@ class AudioMetadata(MetadataObject):
                                   ('start', 0),
                                   ('duration', None),
                                   ('is_segment', None),
+                                  ('sha1', ''),
                                   ('channels', None),
                                   ('channelsManagement', '')])
 
@@ -427,7 +436,12 @@ class DataObject(MetadataObject):
                                            key).tolist().__repr__(),
                                        dtype=h5py.special_dtype(vlen=str))
             else:
-                h5group.create_dataset(key, data=self.__getattribute__(key))
+                if numpy.prod(self.__getattribute__(key).shape):
+                    maxshape = None
+                else:
+                    maxshape = (None,)
+                h5group.create_dataset(
+                    key, data=self.__getattribute__(key), maxshape=maxshape)
 
     def from_hdf5(self, h5group):
         for key, dataset in h5group.items():
@@ -624,25 +638,43 @@ class AnalyzerResult(MetadataObject):
     def _render_plot(self, ax):
         return NotImplemented
 
-    def render(self, size=(1024, 256), dpi=80):
+    def render(self):
+        '''Render a matplotlib figure from the analyzer result
 
+           Return the figure, use fig.show() to display if neeeded
+        '''
+        # TODO : this may crash if the data array is too large
+        # possible workaround downsampled the data
+        #  and plot center, min, max values
+        # see http://stackoverflow.com/a/8881973
+
+        fig, ax = plt.subplots()
+        self._render_plot(ax)
+        return fig
+
+    def _render_PIL(self, size=(1024, 256), dpi=80):
+        from ..grapher.core import Image
         image_width, image_height = size
 
         xSize = image_width / dpi
         ySize = image_height / dpi
 
-        fig = plt.figure(figsize=(xSize, ySize), dpi=dpi)
+        fig = Figure(figsize=(xSize, ySize), dpi=dpi)
+
+        ax = fig.add_axes([0, 0, 1, 1], frame_on=False)
 
-        ax = plt.Axes(fig, [0, 0, 1, 1])
-        ax.set_frame_on(False)
         self._render_plot(ax)
 
-#        ax.axis('off')
-       # ax.axis('tight')
         ax.autoscale(axis='x', tight=True)
-        fig.add_axes(ax)
 
-        return fig
+        # Export to PIL image
+        from StringIO import StringIO
+        imgdata = StringIO()
+        canvas = FigureCanvas(fig)
+        canvas.print_png(imgdata, dpi=dpi)
+        imgdata.seek(0)  # rewind the data
+
+        return Image.open(imgdata)
 
     @property
     def data_mode(self):
@@ -792,11 +824,13 @@ class GlobalLabelResult(LabelObject, GlobalObject, AnalyzerResult):
 
 
 class FrameValueResult(ValueObject, FramewiseObject, AnalyzerResult):
+
     def _render_plot(self, ax):
         ax.plot(self.time, self.data)
 
 
 class FrameLabelResult(LabelObject, FramewiseObject, AnalyzerResult):
+
     def _render_plot(self, ax):
         pass
 
@@ -804,19 +838,21 @@ class FrameLabelResult(LabelObject, FramewiseObject, AnalyzerResult):
 class EventValueResult(ValueObject, EventObject, AnalyzerResult):
     pass
 
+
 class EventLabelResult(LabelObject, EventObject, AnalyzerResult):
     pass
 
+
 class SegmentValueResult(ValueObject, SegmentObject, AnalyzerResult):
+
     def _render_plot(self, ax):
-        import itertools
-        colors = itertools.cycle(['b', 'g', 'r', 'c', 'm', 'y', 'k'])
         for time, value in (self.time, self.data):
             ax.axvline(time, ymin=0, ymax=value, color='r')
             # TODO : check value shape !!!
 
 
 class SegmentLabelResult(LabelObject, SegmentObject, AnalyzerResult):
+
     def _render_plot(self, ax):
         import itertools
         colors = itertools.cycle(['b', 'g', 'r', 'c', 'm', 'y', 'k'])
@@ -824,24 +860,24 @@ class SegmentLabelResult(LabelObject, SegmentObject, AnalyzerResult):
         for key in self.label_metadata.label.keys():
             ax_color[key] = colors.next()
         for time, duration, label in zip(self.time, self.duration, self.data):
-            ax.axvspan(time, time+duration, color=ax_color[label], alpha=0.3)
+            ax.axvspan(time, time + duration, color=ax_color[label], alpha=0.3)
 
 
 class AnalyzerResultContainer(dict):
 
     '''
     >>> import timeside
-    >>> wavFile = 'http://github.com/yomguy/timeside-samples/raw/master/samples/sweep.mp3'
-    >>> d = timeside.decoder.FileDecoder(wavFile)
+    >>> from timeside.analyzer.core import Analyzer
+    >>> wav_file = 'tests/samples/sweep.mp3' # doctest: +SKIP
+    >>> d = timeside.decoder.file.FileDecoder(wav_file)
 
-    >>> a = timeside.analyzer.Analyzer()
+    >>> a = Analyzer()
     >>> (d|a).run()
     >>> a.new_result() #doctest: +ELLIPSIS
-    FrameValueResult(id_metadata=IdMetadata(id='analyzer', name='Generic analyzer', unit='', description='', date='...', version='...', author='TimeSide', uuid='...'), data_object=DataObject(value=array([], dtype=float64)), audio_metadata=AudioMetadata(uri='...', start=0.0, duration=8.0..., is_segment=False, channels=None, channelsManagement=''), frame_metadata=FrameMetadata(samplerate=44100, blocksize=8192, stepsize=8192), parameters={})
+    FrameValueResult(id_metadata=IdMetadata(id='analyzer', name='Generic analyzer', unit='', description='', date='...', version='...', author='TimeSide', uuid='...'), data_object=DataObject(value=array([], dtype=float64)), audio_metadata=AudioMetadata(uri='...', start=0.0, duration=8.0..., is_segment=False, sha1='...', channels=2, channelsManagement=''), frame_metadata=FrameMetadata(samplerate=44100, blocksize=8192, stepsize=8192), parameters={})
     >>> resContainer = timeside.analyzer.core.AnalyzerResultContainer()
     '''
 
-
     def __init__(self, analyzer_results=None):
         super(AnalyzerResultContainer, self).__init__()
         if analyzer_results is not None:
@@ -899,7 +935,11 @@ class AnalyzerResultContainer(dict):
             if isinstance(obj, numpy.ndarray):
                 return {'numpyArray': obj.tolist(),
                         'dtype': obj.dtype.__str__()}
-            raise TypeError(repr(obj) + " is not JSON serializable")
+            elif isinstance(obj, numpy.generic):
+                return numpy.asscalar(obj)
+            else:
+                print type(obj)
+                raise TypeError(repr(obj) + " is not JSON serializable")
 
         json_str = json.dumps([res.as_dict() for res in self.values()],
                               default=NumpyArrayEncoder)
@@ -1016,6 +1056,8 @@ class Analyzer(Processor):
     Generic class for the analyzers
     '''
 
+    type = 'analyzer'
+
     def __init__(self):
         super(Analyzer, self).__init__()
 
@@ -1080,9 +1122,11 @@ class Analyzer(Processor):
         result.id_metadata.uuid = self.uuid()
 
         result.audio_metadata.uri = self.mediainfo()['uri']
+        result.audio_metadata.sha1 = self.mediainfo()['sha1']
         result.audio_metadata.start = self.mediainfo()['start']
         result.audio_metadata.duration = self.mediainfo()['duration']
         result.audio_metadata.is_segment = self.mediainfo()['is_segment']
+        result.audio_metadata.channels = self.channels()
 
         if time_mode == 'framewise':
             result.frame_metadata.samplerate = self.result_samplerate
@@ -1091,7 +1135,10 @@ class Analyzer(Processor):
 
         return result
 
+DOCTEST_ALIAS = {'wav_file':
+                 'https://github.com/yomguy/timeside-samples/raw/master/samples/sweep.mp3'}
+
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod()
+    doctest.testmod(extraglobs=DOCTEST_ALIAS)
