@@ -26,15 +26,17 @@
 # Guillaume Pellerin <yomguy@parisson.com>
 # Thomas Fillon <thomas@parisson.com>
 
-
-from timeside.decoder.core import *
+from timeside.core import implements, interfacedoc
+from timeside.decoder.core import Decoder, IDecoder
+import numpy as np
 
 
 class ArrayDecoder(Decoder):
+
     """ Decoder taking Numpy array as input"""
     implements(IDecoder)
 
-    output_blocksize = 8*1024
+    output_blocksize = 8 * 1024
 
     # IProcessor methods
 
@@ -65,14 +67,15 @@ class ArrayDecoder(Decoder):
         if samples.ndim == 1:
             samples = samples[:, np.newaxis]  # reshape to 2D array
 
-        self.samples = samples  # Create a 2 dimensions array
+        self.samples = samples.astype('float32')  # Create a 2 dimensions array
         self.input_samplerate = samplerate
         self.input_channels = self.samples.shape[1]
 
         self.uri = '_'.join(['raw_audio_array',
                             'x'.join([str(dim) for dim in samples.shape]),
                              samples.dtype.type.__name__])
-
+        from .utils import sha1sum_numpy
+        self._sha1 = sha1sum_numpy(self.samples)
         self.frames = self.get_frames()
 
     def setup(self, channels=None, samplerate=None, blocksize=None):
@@ -116,7 +119,7 @@ class ArrayDecoder(Decoder):
         for index in xrange(0,
                             nb_frames * self.output_blocksize,
                             self.output_blocksize):
-            yield (self.samples[index:index+self.output_blocksize], False)
+            yield (self.samples[index:index + self.output_blocksize], False)
 
         yield (self.samples[nb_frames * self.output_blocksize:], True)
 
@@ -124,17 +127,20 @@ class ArrayDecoder(Decoder):
     def process(self):
         return self.frames.next()
 
-    ## IDecoder methods
+    # IDecoder methods
     @interfacedoc
     def format(self):
         import re
         base_type = re.search('^[a-z]*', self.samples.dtype.name).group(0)
-        return 'audio/x-raw-'+base_type
+        return 'audio/x-raw-' + base_type
 
     @interfacedoc
     def metadata(self):
         return None
 
+    @interfacedoc
+    def release(self):
+        self.frames = self.get_frames()
 
 if __name__ == "__main__":
     import doctest
