@@ -28,18 +28,23 @@
 
 from __future__ import division
 
-from timeside.decoder.core import *
-from timeside.tools.gstutils import MainloopThread
+from timeside.decoder.core import Decoder, IDecoder, interfacedoc, implements
+from timeside.tools.gstutils import MainloopThread, gobject
+from . file import FileDecoder
+import Queue
+import threading
+
+from gst import _gst as gst
+
+GST_APPSINK_MAX_BUFFERS = 10
+QUEUE_SIZE = 10
 
 
-class LiveDecoder(Decoder):
+class LiveDecoder(FileDecoder):
     """ gstreamer-based decoder from live source"""
     implements(IDecoder)
 
-    output_blocksize = 8*1024
-
-    pipeline = None
-    mainloopthread = None
+    # IProcessor methods
 
     @staticmethod
     @interfacedoc
@@ -47,7 +52,6 @@ class LiveDecoder(Decoder):
         return "gst_live_dec"
 
     def __init__(self, num_buffers=-1, input_src='autoaudiosrc'):
-
         """
         Construct a new LiveDecoder capturing audio from alsasrc
 
@@ -63,9 +67,10 @@ class LiveDecoder(Decoder):
 
         >>> import timeside
 
-        >>> live = timeside.decoder.LiveDecoder(num_buffers=5)
-        >>> a = timeside.analyzer.Waveform()
-        >>> e = timeside.encoder.Mp3Encoder('/tmp/test_live.mp3',
+        >>> from timeside.core import get_processor
+        >>> live = timeside.decoder.live.LiveDecoder(num_buffers=5)
+        >>> a = get_processor('waveform_analyzer')()
+        >>> e = timeside.encoder.mp3.Mp3Encoder('/tmp/test_live.mp3',
         ...                                 overwrite=True)
         >>> pipe = (live | a | e)
         >>> pipe.run() # doctest: +SKIP
@@ -85,6 +90,7 @@ class LiveDecoder(Decoder):
         self.uri_duration = None
         self.is_segment = False
         self.input_src = input_src
+        self._sha1 = ''
 
     def setup(self, channels=None, samplerate=None, blocksize=None):
 
@@ -92,7 +98,6 @@ class LiveDecoder(Decoder):
         self.last_buffer = None
 
         # a lock to wait wait for gstreamer thread to be ready
-        import threading
         self.discovered_cond = threading.Condition(threading.Lock())
         self.discovered = False
 
@@ -155,7 +160,7 @@ class LiveDecoder(Decoder):
 
         self.discovered_cond.acquire()
         while not self.discovered:
-            #print 'waiting'
+            # print 'waiting'
             self.discovered_cond.wait()
         self.discovered_cond.release()
 
@@ -165,85 +170,6 @@ class LiveDecoder(Decoder):
             else:
                 raise IOError('no known audio stream found')
 
-    def _notify_caps_cb(self, pad, args):
-        self.discovered_cond.acquire()
-
-        caps = pad.get_negotiated_caps()
-        if not caps:
-            pad.info("no negotiated caps available")
-            self.discovered = True
-            self.discovered_cond.notify()
-            self.discovered_cond.release()
-            return
-        # the caps are fixed
-        # We now get the total length of that stream
-        q = gst.query_new_duration(gst.FORMAT_TIME)
-        pad.info("sending duration query")
-        if pad.get_peer().query(q):
-            format, length = q.parse_duration()
-            if format == gst.FORMAT_TIME:
-                pad.info("got duration (time) : %s" % (gst.TIME_ARGS(length),))
-            else:
-                pad.info("got duration : %d [format:%d]" % (length, format))
-        else:
-            length = -1
-            gst.warning("duration query failed")
-
-        # We store the caps and length in the proper location
-        if "audio" in caps.to_string():
-            self.input_samplerate = caps[0]["rate"]
-            if not self.output_samplerate:
-                self.output_samplerate = self.input_samplerate
-            self.input_channels = caps[0]["channels"]
-            if not self.output_channels:
-                self.output_channels = self.input_channels
-            self.input_duration = length / 1.e9
-
-            self.input_totalframes = int(self.input_duration * self.input_samplerate)
-            if "x-raw-float" in caps.to_string():
-                self.input_width = caps[0]["width"]
-            else:
-                self.input_width = caps[0]["depth"]
-
-        self.discovered = True
-        self.discovered_cond.notify()
-        self.discovered_cond.release()
-
-    def _on_message_cb(self, bus, message):
-        t = message.type
-        if t == gst.MESSAGE_EOS:
-            self.queue.put(gst.MESSAGE_EOS)
-            self.pipeline.set_state(gst.STATE_NULL)
-            self.mainloop.quit()
-        elif t == gst.MESSAGE_ERROR:
-            self.pipeline.set_state(gst.STATE_NULL)
-            err, debug = message.parse_error()
-            self.discovered_cond.acquire()
-            self.discovered = True
-            self.mainloop.quit()
-            self.error_msg = "Error: %s" % err, debug
-            self.discovered_cond.notify()
-            self.discovered_cond.release()
-        elif t == gst.MESSAGE_TAG:
-            # TODO
-            # msg.parse_tags()
-            pass
-
-    def _on_new_buffer_cb(self, sink):
-        buf = sink.emit('pull-buffer')
-        new_array = gst_buffer_to_numpy_array(buf, self.output_channels)
-
-        #print 'processing new buffer', new_array.shape
-        if self.last_buffer is None:
-            self.last_buffer = new_array
-        else:
-            self.last_buffer = np.concatenate((self.last_buffer, new_array), axis=0)
-        while self.last_buffer.shape[0] >= self.output_blocksize:
-            new_block = self.last_buffer[:self.output_blocksize]
-            self.last_buffer = self.last_buffer[self.output_blocksize:]
-            #print 'queueing', new_block.shape, 'remaining', self.last_buffer.shape
-            self.queue.put([new_block, False])
-
     @interfacedoc
     def process(self):
         buf = self.queue.get()
@@ -253,42 +179,11 @@ class LiveDecoder(Decoder):
         frames, eod = buf
         return frames, eod
 
-    @interfacedoc
-    def totalframes(self):
-        if self.input_samplerate == self.output_samplerate:
-            return self.input_totalframes
-        else:
-            ratio = self.output_samplerate / self.input_samplerate
-            return int(self.input_totalframes * ratio)
-
-    @interfacedoc
     def release(self):
-        if self.stack:
-            self.stack = False
-            self.from_stack = True
+        # TODO : check if stack support is needed here
+        #if self.stack:
+        #    self.stack = False
+        #    self.from_stack = True
         pass
 
-    ## IDecoder methods
-
-    @interfacedoc
-    def format(self):
-        # TODO check
-        if self.mimetype == 'application/x-id3':
-            self.mimetype = 'audio/mpeg'
-        return self.mimetype
-
-    @interfacedoc
-    def encoding(self):
-        # TODO check
-        return self.mimetype.split('/')[-1]
-
-    @interfacedoc
-    def resolution(self):
-        # TODO check: width or depth?
-        return self.input_width
-
-    @interfacedoc
-    def metadata(self):
-        # TODO check
-        return self.tags
-
+    # IDecoder methods
